@@ -14,6 +14,10 @@ function _aws_cdk_aws_xray_CfnGroup(p) {
 }
 function _aws_cdk_aws_xray_CfnGroup_InsightsConfigurationProperty(p) {
 }
+function _aws_cdk_aws_xray_CfnResourcePolicyProps(p) {
+}
+function _aws_cdk_aws_xray_CfnResourcePolicy(p) {
+}
 function _aws_cdk_aws_xray_CfnSamplingRuleProps(p) {
 }
 function _aws_cdk_aws_xray_CfnSamplingRule(p) {
@@ -60,4 +64,4 @@ class DeprecationError extends Error {
         });
     }
 }
-module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_xray_CfnGroupProps, _aws_cdk_aws_xray_CfnGroup, _aws_cdk_aws_xray_CfnGroup_InsightsConfigurationProperty, _aws_cdk_aws_xray_CfnSamplingRuleProps, _aws_cdk_aws_xray_CfnSamplingRule, _aws_cdk_aws_xray_CfnSamplingRule_SamplingRuleProperty, _aws_cdk_aws_xray_CfnSamplingRule_SamplingRuleRecordProperty, _aws_cdk_aws_xray_CfnSamplingRule_SamplingRuleUpdateProperty };
+module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_xray_CfnGroupProps, _aws_cdk_aws_xray_CfnGroup, _aws_cdk_aws_xray_CfnGroup_InsightsConfigurationProperty, _aws_cdk_aws_xray_CfnResourcePolicyProps, _aws_cdk_aws_xray_CfnResourcePolicy, _aws_cdk_aws_xray_CfnSamplingRuleProps, _aws_cdk_aws_xray_CfnSamplingRule, _aws_cdk_aws_xray_CfnSamplingRule_SamplingRuleProperty, _aws_cdk_aws_xray_CfnSamplingRule_SamplingRuleRecordProperty, _aws_cdk_aws_xray_CfnSamplingRule_SamplingRuleUpdateProperty };
